@@ -154,16 +154,7 @@ sub read_value {
     });
 
     unless ( $value_sector ) {
-        $value_sector = DBM::Deep::Sector::File::Null->new({
-            engine => $self,
-            data   => undef,
-        });
-
-        $sector->write_data({
-            key_md5 => $key_md5,
-            key     => $key,
-            value   => $value_sector,
-        });
+        return undef
     }
 
     return $value_sector->data;
